#!/bin/bash
#===============================================================================
#   vidlength.sh    |   Version 1.0     |   FreeBSD License     |   2014-01-24
#   James Hendrie   |   hendrie dot james at gmail dot com
#===============================================================================

PROGRAM=ffprobe

function print_help
{
    echo -e "\nUsage:\tvidlength VIDEO_FILE"
    echo -e "This script tells you how long a video file is.  That's all."
}

#   Check to ensure they have ffprobe
which ${PROGRAM} &> /dev/null
if [ $? -ne 0 ]; then
    echo "ERROR:  Program '${PROGRAM}' required" 1>&2
    exit 1
fi

#   Check to make sure the user used at least one arg
if [ $# -lt 1 ]; then
    echo -e "\nERROR:  Need at least one argument" 2>&1
    print_help
    exit 1
fi


#   Check if they want help
if [ "$1" = "-h" ] || [ "$1" = "--help" ]; then
    print_help
    exit 0
fi


#   Do the stuff
for i in "$@"; do
    DURSTRING=$(${PROGRAM} "$i" 2>&1 | grep Duration | cut -f1 -d',')
    HR=$(echo "$DURSTRING" | cut -f2 -d':' | tr -d ' ')
    MIN=$(echo "$DURSTRING" | cut -f3 -d':')
    SEC=$(echo "$DURSTRING" | cut -f4 -d':')

    echo "$HR hours, $MIN minutes and $SEC seconds"
done
